Solid
=====

.. toctree::

   combinations <solid/combinations>
   exporters <solid/exporters>
   features <solid/features>
   importers <solid/importers>
   primitives <solid/primitives>
   topologies <solid/topologies>
   transformations <solid/transformations>
   types <solid/types>
